"""
Copyright 2014-2015 Rackspace

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""
from functionaltests.api.v1.models import base_models


class ConsumerModel(base_models.BaseModel):

    def __init__(self, name=None, URL=None, created=None, updated=None,
                 status=None):
        super(ConsumerModel, self).__init__()
        self.name = name
        self.URL = URL
        self.created = created
        self.updated = updated
        self.status = status
